#!/bin/sh
#***************************************************
#USE THE "vars.txt" commands to prepare the environment variables we will use.
#***************************************************

##################################################
# Introduction
##################################################

#The kernel can boot up directly into rootfs or use an intermediate initramfs image.
#OverlayFS feature needs initramfs."


#I used BUSYBOX to reduce its size and had to write the init script from scratch (see credits section).

##################################################
# Create Initramfs staging directory
##################################################
RFShddPATH=/media/rootfs_
#RFShddCFG=$RFShddPATH/multistrap-hdd.cfg
RFShdd=$RFShddPATH

ASMAC=00:50:43:00:02:02
NASIP=192.168.178.28
NASGW=192.168.178.254
NASHOSTNAME=nsa325-v2

UBOOTWORKDIR=/root/nas/nsa325/uboot

KERNELWORKDIR=/root/nas/nsa325/kernel
KERNELCURRENT=linux-3.14.5

NASINITRAMFS=/root/nas/nsa325/initramfs+root-ro
NASINITRAMFSNAME="initrd.img-3.14.5-tld-1"

mkdir -p $NASINITRAMFS/stage
cd $NASINITRAMFS

mkdir -p $NASINITRAMFS/stage/bin
mkdir -p $NASINITRAMFS/stage/scripts


# UNTESTED/NOT SUPPORTED:
	# If you need KERNEL MODULES to load your root device, please don't!
	# Just compile support in kernel, it's easier.
	# If you still need it, you may try with;
	mkdir -p $NASINITRAMFS/stage/lib/modules
	cd ${KERNELWORKDIR}
	make INSTALL_MOD_PATH=$NASINITRAMFS/stage modules_install
	cd -


# Get Busybox ARM binary

wget http://busybox.net/downloads/binaries/latest/busybox-armv5l -O $NASINITRAMFS/stage/bin/busybox
chmod +x $NASINITRAMFS/stage/bin/busybox
ln -sf busybox $NASINITRAMFS/stage/bin/sh


# This script will automate the build process of initramfs image
#cat <<EOF > $NASINITRAMFS/make-uInitramfs
#!/bin/sh
cd stage
find . | cpio -H newc -o | gzip >../uInitramfs.cpio.gz
cd ..
mkimage -A arm -O linux -T ramdisk -C gzip -a 0x00000000 -e 0x00000000 -n $NASINITRAMFSNAME -d uInitramfs.cpio.gz uInitrd 
#EOF

chmod +x $NASINITRAMFS/make-uInitramfs


##################################################
# INITRAMFS INIT SCRIPTs
##################################################

#Now copy these files into the staging directory:
#
#	init
#	scripts/local
#	scripts/functions
#
#Ensure init is executable
chmod +x $NASINITRAMFS/stage/init


##################################################
# OVERLAYFS support
##################################################
#	
#If you want OverlayFS support:
#
#Copy into staging directory:
#	scripts/init-bottom/root-ro-overlayfs

chmod +x $NASINITRAMFS/stage/scripts/init-bottom/root-ro-overlayfs



##################################################
# COMPILE INITRAMS
##################################################

#Make Image:
#cd $NASINITRAMFS
##./make-uInitramfs
#	2199 blocks
#	Image Name:   NSA-325-v2-Initramfs
#	Created:      Thu May  8 23:33:06 2014
#	Image Type:   ARM Linux RAMDisk Image (gzip compressed)
#	Data Size:    632222 Bytes = 617.40 kB = 0.60 MB
#	Load Address: 00000000
#	Entry Point:  00000000



##################################################
# INSTALL INITRAMFS INTO ROOTFS
##################################################

#- COPY uInitramfs to RootFS for NAND:

cp $NASINITRAMFS/uInitrd $RFShdd/boot/uInitrd



#######################################################################################################################
## Credits: 
## http://wiki.sourcemage.org/HowTo%282f%29Initramfs.html
## The Debian Initramfs package
## https://help.ubuntu.com/community/aufsRootFileSystemOnUsbFlash
#######################################################################################################################
